@@ -72,6 +72,8 @@ int _comedi_sv_update(comedi_sv_t *it)
 EXPORT_ALIAS_DEFAULT(_comedi_sv_measure,comedi_sv_measure,0.7.18);
 int _comedi_sv_measure(comedi_sv_t *it,double *data)
 {
+	if(!it)return -1;
+	if(!valid_subd(it->dev,it->subdevice))return -1;
 	if(it->dev->subdevices[it->subdevice].subd_flags & SDF_LSAMPL){
 		return sv_measure_l(it,data);
 	}else{
@@ -93,7 +95,7 @@ int sv_measure_l(comedi_sv_t *it,double *data)
 	val=malloc(sizeof(*val)*it->n);
 
 	chan=CR_PACK(it->chan,it->range,it->aref);
-	
+
 	t.subdev=it->subdevice;
 	t.mode=0;
 	t.flags=TRIG_DITHER;
@@ -108,7 +110,7 @@ int sv_measure_l(comedi_sv_t *it,double *data)
 	for(n=0;n<it->n;){
 		t.data=(void *)(val+n);
 		t.n=it->n-n;
-		i = comedi_ioctl(it->dev->fd, COMEDI_TRIG, (unsigned long)&t);
+		i = comedi_ioctl(it->dev->fd, COMEDI_TRIG, &t);
 		if(i<=0){
 			ret=i;
 			goto out;
@@ -144,7 +146,7 @@ int sv_measure_s(comedi_sv_t *it,double *data)
 	val=malloc(sizeof(*val)*it->n);
 
 	chan=CR_PACK(it->chan,it->range,it->aref);
-	
+
 	t.subdev=it->subdevice;
 	t.mode=0;
 	t.flags=TRIG_DITHER;
@@ -161,7 +163,7 @@ int sv_measure_s(comedi_sv_t *it,double *data)
 	for(n=0;n<it->n;){
 		t.data=val+n;
 		t.n=it->n-n;
-		i = comedi_ioctl(it->dev->fd, COMEDI_TRIG, (unsigned long)&t);
+		i = comedi_ioctl(it->dev->fd, COMEDI_TRIG, &t);
 		if(i<=0){
 			ret=i;
 			goto out;
