@@ -112,7 +112,7 @@ int test_cmd_read_fast_1chan(void)
 	int ret;
 	unsigned int flags = comedi_get_subdevice_flags(device,subdevice);
 
-	if(!(flags&SDF_CMD) || flags&SDF_WRITEABLE){
+	if(!(flags&SDF_CMD) || (comedi_get_read_subdevice(device)!=subdevice)){
 		printf("not applicable\n");
 		return 0;
 	}
@@ -172,7 +172,7 @@ int test_cmd_write_fast_1chan(void)
 	{
 		num_bytes = num_samples * sizeof(sampl_t);
 	}
-	if(!(flags&SDF_CMD) || !(flags&SDF_WRITEABLE)){
+	if(!(flags&SDF_CMD) || (comedi_get_write_subdevice(device)!=subdevice)){
 		printf("not applicable\n");
 		return 0;
 	}
@@ -181,6 +181,7 @@ int test_cmd_write_fast_1chan(void)
 		printf("  not supported\n");
 		return 0;
 	}
+	cmd.flags |= CMDF_WRITE;
 
 	if(realtime)cmd.flags |= TRIG_RT;
 	cmd.chanlist = chanlist;
@@ -217,7 +218,7 @@ int test_cmd_write_fast_1chan(void)
 
 	ret = comedi_internal_trigger(device, subdevice, 0);
 	if(ret<0){
-		perror("E: comedi_inttrig");
+		comedi_perror("E: comedi_internal_trigger");
 		comedi_cancel(device, subdevice);
 		return 0;
 	}
