@@ -22,10 +22,6 @@
 
 #define N_SAMPLES 10000
 
-#define BUFSZ N_SAMPLES*sizeof(sampl_t)
-
-#define MAPLEN 20480
-
 sigjmp_buf jump_env;
 
 void segv_handler(int num)
@@ -68,29 +64,34 @@ int test_mmap(void)
 	unsigned char *map;
 	unsigned int flags;
 	int i;
+	unsigned sample_size;
+	unsigned map_len;
 
 	flags = comedi_get_subdevice_flags(device,subdevice);
 
-	if(!(flags&SDF_CMD) || flags&SDF_WRITEABLE){
+	if(!(flags&SDF_CMD) || (comedi_get_read_subdevice(device)!=subdevice)){
 		printf("not applicable\n");
 		return 0;
 	}
+	if(flags & SDF_LSAMPL) sample_size = sizeof(lsampl_t);
+	else sample_size = sizeof(sampl_t);
+	map_len = sample_size * N_SAMPLES;
 
 	if(comedi_get_cmd_generic_timed(device, subdevice, &cmd, 1, 1)<0){
 		printf("E: comedi_get_cmd_generic_timed failed\n");
 		return 0;
 	}
 
-	buf=malloc(BUFSZ);
+	buf=malloc(sample_size * N_SAMPLES);
 
-	map=mmap(NULL,MAPLEN,PROT_READ,MAP_SHARED,comedi_fileno(device),0);
+	map = mmap(NULL, map_len,PROT_READ, MAP_SHARED, comedi_fileno(device),0);
 	if(!map){
 		printf("E: mmap() failed\n");
 		return 0;
 	}
 
 	/* test readability */
-	for(adr=map;adr<map+MAPLEN;adr+=PAGE_SIZE){
+	for(adr = map; adr < map + map_len; adr += PAGE_SIZE){
 		ret=test_segfault(adr);
 		if(ret){
 			printf("E: %p failed\n",adr);
@@ -112,7 +113,8 @@ int test_mmap(void)
 	go=1;
 	b=buf;
 	while(go){
-		ret = read(comedi_fileno(device),b,BUFSZ);
+		ret = read(comedi_fileno(device), b,
+				(N_SAMPLES * sample_size) - total);
 		if(ret<0){
 			if(errno==EAGAIN){
 				usleep(10000);
@@ -126,6 +128,9 @@ int test_mmap(void)
 			total += ret;
 			b += ret;
 			if(verbose) printf("read %d %d\n",ret,total);
+			if(total >= (N_SAMPLES * sample_size)){
+				go = 0;
+			}
 		}
 	}
 
@@ -135,17 +140,16 @@ int test_mmap(void)
 			if(fails==0)printf("E: mmap compare failed\n");
 			printf("offset %d (read=%02x mmap=%02x)\n",i,
 				buf[i], map[i]);
-			go = 0;
 			fails++;
 			if(fails>10)break;
 		}
 	}
 	if(fails==0) printf("compare ok\n");
 
-	munmap(map,MAPLEN);
+	munmap(map, map_len);
 
 	/* test if area is really unmapped */
-	for(adr=map;adr<map+MAPLEN;adr+=PAGE_SIZE){
+	for(adr = map; adr < map + map_len; adr += PAGE_SIZE){
 		ret=test_segfault(adr);
 		if(ret){
 			printf("%p segfaulted (ok)\n",adr);
